function [P] = chebyshev(x,M,a)

%evaluate an M-1 th Chebyshev polynomial with parameters, a, at a vector, x, of points.

[N,n]=size(x);

if n>1 
    error('fatal (chebyshev) input points must be a column vector')
end

phi=(2*x-1)';

if size(a,1) ~= M
    error('fatal (chebyshev) wrong number of parameters')
end
if size(a,2) ~= 1
    error('fatal (chebyshev) must be a column vector')
end
if M < 3
    error('fatal (chebyshev) must be quadratic or higher order')
end

T=zeros(M,N);
T(1,:)=ones(1,N);
T(2,:)=phi;

if M >= 3
    for ii = 3:M
        T(ii,:)=2*phi.*T(ii-1,:)-T(ii-2,:);
    end
end

P=(a'*T)';
